@@ -1,14 +1,16 @@
 package configmetrics
 
 import (
+	"github.com/blang/semver"
 	"github.com/prometheus/client_golang/prometheus"
+	"k8s.io/component-base/metrics/legacyregistry"
 
 	configinformers "github.com/openshift/client-go/config/informers/externalversions"
 	configlisters "github.com/openshift/client-go/config/listers/config/v1"
 )
 
 func Register(configInformer configinformers.SharedInformerFactory) {
-	prometheus.MustRegister(&configMetrics{
+	legacyregistry.MustRegister(&configMetrics{
 		configLister: configInformer.Config().V1().Schedulers().Lister(),
 		config: prometheus.NewGauge(prometheus.GaugeOpts{
 			Name: "cluster_master_schedulable",
@@ -23,6 +25,10 @@ type configMetrics struct {
 	config       prometheus.Gauge
 }
 
+func (m *configMetrics) Create(version *semver.Version) bool {
+	return true
+}
+
 // Describe reports the metadata for metrics to the prometheus collector.
 func (m *configMetrics) Describe(ch chan<- *prometheus.Desc) {
 	ch <- m.config.Desc()
